@@ -21,7 +21,7 @@ use Spreadsheet::WriteExcel::Workbook;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::WriteExcel::Workbook Exporter);
 
-$VERSION = '0.31'; #  April 12 2001, Lou, Lou, Lou.
+$VERSION = '0.32'; #  Weller.
 
 
 
@@ -63,7 +63,7 @@ Spreadsheet::WriteExcel - Write to a cross-platform Excel binary file.
 
 =head1 VERSION
 
-This document refers to version 0.31 of Spreadsheet::WriteExcel, released April 12, 2001.
+This document refers to version 0.32 of Spreadsheet::WriteExcel, released May 17, 2001.
 
 
 
@@ -81,7 +81,7 @@ To write a string, a formatted string, a number and a formula to the first works
     $worksheet = $workbook->addworksheet();
 
     #  Add and define a format
-    $format = $workbook->addformat();    # Add a format
+    $format = $workbook->addformat(); # Add a format
     $format->set_bold();
     $format->set_color('red');
     $format->set_align('center');
@@ -142,7 +142,7 @@ You can also pass a valid filehandle to the C<new()> constructor. For example in
 
 The requirement for C<binmode()> is explained below.
 
-For CGI programs you can also use the special Perl filename C<'-'> which will redirect the output to STDOUT,:
+For CGI programs you can also use the special Perl filename C<'-'> which will redirect the output to STDOUT:
 
     my $workbook  = Spreadsheet::WriteExcel->new('-');
 
@@ -154,7 +154,7 @@ See also, the C<cgi.pl> program in the C<examples> directory of the distro. Howe
 
 Filehandles can also be useful if you want to stream an Excel file over a socket or if you want to store an Excel file in a tied scalar. For some examples of using filehandles with Spreadsheet::WriteExcel see the C<filehandle.pl> program in the C<examples> directory of the distro.
 
-Note: an Excel file is comprised of binary data. Therefore, if you are using a filehandle you should ensure that you C<binmode()> it prior to passing it to C<new()>.You should do this regardless of whether your platform requires it or not. For more information about C<binmode()> see C<perlfunc> and C<perlopentut> in the main Perl documentation. You do not need to C<binmode()> a filename. In fact it would cause an error. Spreadsheet::WriteExcel performs the C<binmode()> internally when it converts the filename to a filehandle.
+Note about the requirement for C<binmode()>: An Excel file is comprised of binary data. Therefore, if you are using a filehandle you should ensure that you C<binmode()> it prior to passing it to C<new()>.You should do this regardless of whether your platform requires it or not. For more information about C<binmode()> see C<perlfunc> and C<perlopentut> in the main Perl documentation. It is equally important to note that you do not need to C<binmode()> a filename. In fact it would cause an error. Spreadsheet::WriteExcel performs the C<binmode()> internally when it converts the filename to a filehandle.
 
 
 
@@ -187,7 +187,7 @@ In general, if you create a file with a size of 0 bytes you need to call C<close
 
 =head2 addworksheet($sheetname)
 
-At least one worksheet should be added to a new workbook:
+At least one worksheet should be added to a new workbook. A worksheet is used to write data into cells:
 
     $worksheet1 = $workbook->addworksheet();          # Sheet1
     $worksheet2 = $workbook->addworksheet('Foglio2'); # Foglio2
@@ -358,9 +358,9 @@ Write a formula or function to the cell specified by C<$row> and C<$column>:
 
     $worksheet->write_formula(0, 0, '=$B$3 + B4'  );
     $worksheet->write_formula(1, 0, '=SIN(PI()/4)');
-    $worksheet->write_formula(2, 0, '=SUM(B1:B5)');
-    $worksheet->write_formula('A4', '=IF(A3>1,"Yes", "No")');
-    $worksheet->write_formula('A5', '=AVERAGE(1, 2, 3, 4)');
+    $worksheet->write_formula(2, 0, '=SUM(B1:B5)' );
+    $worksheet->write_formula('A4', '=IF(A3>1,"Yes", "No")'   );
+    $worksheet->write_formula('A5', '=AVERAGE(1, 2, 3, 4)'    );
     $worksheet->write_formula('A6', '=DATEVALUE("1-Jan-2001")');
 
 See the note about L<Cell notation>. For more information about writing Excel formulas see L<FORMULAS AND FUNCTIONS IN EXCEL>
@@ -393,9 +393,11 @@ The label is written using the C<write_string()> method. Therefore the 255 chara
 Note: Hyperlinks are not available in Excel 5. They will appear as a string only.
 
 
+
+
 =head2 activate()
 
-The C<activate()> method is used to specify which worksheet is initially selected in a multi-sheet workbook:
+The C<activate()> method is used to specify which worksheet is initially visible in a multi-sheet workbook:
 
     $worksheet1 = $workbook->addworksheet('To');
     $worksheet2 = $workbook->addworksheet('the');
@@ -403,7 +405,20 @@ The C<activate()> method is used to specify which worksheet is initially selecte
 
     $worksheet3->activate();
 
-This is similar to the Excel VBA activate method. The default value is the first worksheet.
+This is similar to the Excel VBA activate method. More than one worksheet can be selected via the C<select()> method, however only one worksheet can be active. The default value is the first worksheet.
+
+
+
+
+=head2 select()
+
+The C<select()> method is used to indicate that a worksheet is selected in a multi-sheet workbook:
+
+    $worksheet1->activate();
+    $worksheet2->select();
+    $worksheet3->select();
+
+A selected worksheet has its tab highlighted. Selecting worksheets is a way of grouping them together so that, for example, several worksheets could be printed in one go.. A worksheet that has been activated via the C<activate()> method will also appear as a selected. You probably won't need to use the C<select()> method very often.
 
 
 
@@ -473,6 +488,307 @@ If you wish to set the format without changing the width you can pass C<undef> a
 
     $worksheet->set_column(0, 0, undef, $format);
 
+Unfortunately, there is no way to specify "AutoFit" for a column in the Excel file format. This feature is only available at runtime from within Excel.
+
+
+
+=head2 freeze_panes($row, $col, $top_row, $left_col);
+
+This method can be used to divide a worksheet into horizontal or vertical regions known as panes and to also "freeze" these panes so that the splitter bars are not visible. This is the the same as the "Window->Freeze Panes" menu command in Excel
+
+The parameters C<$row> and C<$col> are used to specify the location of the split. It should be noted that the split is specified at the top or left of a cell and that the method uses zero based indexing. Therefore to freeze the first row of a worksheet it is necessary to specify the split at row 2 (which is 1 as the zero-based index). This might lead you to think that you are using a 1 based index but this is not the case.
+
+You can set one of the C<$row> and C<$col> parameters as zero if you do not want either a vertical or horizontal split. 
+
+Examples:
+
+    $worksheet->freeze_panes(1, 0); # Freeze the first row
+    $worksheet->freeze_panes('A2'); # Same using A1 notation
+    $worksheet->freeze_panes(0, 1); # Freeze the first column
+    $worksheet->freeze_panes('B1'); # Same using A1 notation
+    $worksheet->freeze_panes(1, 2); # Freeze the first row and first 2 columns
+    $worksheet->freeze_panes('C2'); # Same using A1 notation
+
+The parameters C<$top_row> and C<$left_col> are optional. They are used to specify the top-most or left-most visible row or column in the scrolling region of the panes. For example to freeze the first row and to have the scrolling region begin at row twenty:
+
+    $worksheet->freeze_panes(1, 0, 20, 0);
+
+You cannot use A1 notation for the C<$top_row> and C<$left_col> parameters.
+    
+
+See also the C<panes.pl> program in the examples directory of the distribution.
+
+
+
+
+=head2 thaw_panes($y, $x, $top_row, $left_col);
+
+This method can be used to divide a worksheet into horizontal or vertical regions known as panes. This method is different from the C<freeze_panes()> method in that the splits between the panes will be visible to the user and each pane will have its own scroll bars.
+
+The parameters C<$y> and C<$x> are used to specify the vertical and horizontal position of the split. The units for C<$y> and C<$x> are the same as those used by Excel to specify row height and column width. However, the vertical and horizontal units are different from each other. Therefore you must specify the C<$y> and C<$x> parameters in terms of the row heights and column widths that you have set or the default values which are C<12.75> for a row and  C<8.43> for a column.
+
+You can set one of the C<$y> and C<$x> parameters as zero if you do not want either a vertical or horizontal split. The parameters C<$top_row> and C<$left_col> are optional. They are used to specify the top-most or left-most visible row or column in the bottom-right pane.
+
+Example:
+
+    $worksheet->thaw_panes(12.75, 0,    1, 0); # First row
+    $worksheet->thaw_panes(0,     8.43, 0, 1); # First column
+    $worksheet->thaw_panes(12.75, 8.43, 1, 1); # First row and column
+
+You cannot use A1 notation with this method.
+
+See also the C<freeze_panes()> method and the C<panes.pl> program in the examples directory of the distribution.
+
+
+
+
+=head1 PAGE SETUP METHODS
+
+Page setup methods affect the way that a worksheet will look when it is printed. They control features such as page headers and footers and margins. These methods are really just standard worksheet methods. They are documented here in a separate section for the sake of clarity.
+
+Not all of Excel's page setup options are available in this release but they will be added in subsequent releases.
+
+A common requirement when working with Spreadsheet::WriteExcel is to apply the same page setup features to all of the worksheets in a workbook. To do this you can use the the C<worksheets()> method of the C<workbook> class to access the array of worksheets in a workbook:
+
+    foreach $worksheet (@{$workbook->worksheets()}) {
+       $worksheet->$worksheet->set_orientation(0);
+    }
+
+
+
+
+=head2 set_landscape()
+
+This method is used to set the orientation of a worksheet's printed page to landscape:
+
+    $worksheet->set_orientation(); # Landscape mode
+
+
+
+
+=head2 set_portrait()
+
+This method is used to set the orientation of a worksheet's printed page to portrait. The default worksheet orientation is portrait, so you generally won't need to call this method.
+
+    $worksheet->set_portrait(); # Portrait mode
+
+
+
+=head2 set_paper($index)
+
+This method is used to set the paper format for the printed output of a worksheet. The following paper styles are available:
+
+    Index   Paper format            Paper size
+    =====   ============            ==========
+      0     Printer default         -
+      1     Letter                  8 1/2 x 11 in
+      2     Letter Small            8 1/2 x 11 in
+      3     Tabloid                 11 x 17 in
+      4     Ledger                  17 x 11 in
+      5     Legal                   8 1/2 x 14 in
+      6     Statement               5 1/2 x 8 1/2 in
+      7     Executive               7 1/4 x 10 1/2 in
+      8     A3                      297 x 420 mm
+      9     A4                      210 x 297 mm
+     10     A4 Small                210 x 297 mm
+     11     A5                      148 x 210 mm
+     12     B4                      250 x 354 mm
+     13     B5                      182 x 257 mm
+     14     Folio                   8 1/2 x 13 in
+     15     Quarto                  215 x 275 mm
+     16     -                       10x14 in
+     17     -                       11x17 in
+     18     Note                    8 1/2 x 11 in
+     19     Envelope  9             3 7/8 x 8 7/8
+     20     Envelope 10             4 1/8 x 9 1/2
+     21     Envelope 11             4 1/2 x 10 3/8
+     22     Envelope 12             4 3/4 x 11
+     23     Envelope 14             5 x 11 1/2
+     24     C size sheet            -
+     25     D size sheet            -
+     26     E size sheet            -
+     27     Envelope DL             110 x 220 mm
+     28     Envelope C3             324 x 458 mm
+     29     Envelope C4             229 x 324 mm
+     30     Envelope C5             162 x 229 mm
+     31     Envelope C6             114 x 162 mm
+     32     Envelope C65            114 x 229 mm
+     33     Envelope B4             250 x 353 mm
+     34     Envelope B5             176 x 250 mm
+     35     Envelope B6             176 x 125 mm
+     36     Envelope                110 x 230 mm
+     37     Monarch                 3.875 x 7.5 in
+     38     Envelope                3 5/8 x 6 1/2 in
+     39     Fanfold                 14 7/8 x 11 in
+     40     German Std Fanfold      8 1/2 x 12 in
+     41     German Legal Fanfold    8 1/2 x 13 in
+
+
+Note, it is likely that not all of these paper types will be available to the end user since it will depend on the paper formats that the user's printer supports. Therefore, it is best to stick to standard paper types.
+
+If you do not specify a paper type the worksheet will print using the printer's default paper. 
+
+    $worksheet->set_paper(1); # US Letter
+    $worksheet->set_paper(9); # A4
+
+
+
+=head2 center_horizontally()
+
+Center the worksheet data horizontally between the margins on the printed page:
+
+    $worksheet->center_horizontally();
+
+
+
+
+=head2 center_vertically()
+
+Center the worksheet data vertically between the margins on the printed page:
+
+    $worksheet->center_vertically();
+
+
+
+
+=head2 set_margins($inches)
+
+There are several methods available for setting the worksheet margins on the printed page:
+
+    set_margins()        # Set all margins to the same value
+    set_margins_LR()     # Set left and right margins to the same value
+    set_margins_TB()     # Set top and bottom margins to the same value
+    set_margin_left();   # Set left margin
+    set_margin_right();  # Set right margin
+    set_margin_top();    # Set top margin
+    set_margin_bottom(); # Set bottom margin
+
+All of these methods take a distance in inches as a parameter. Note: 1 inch = 25.4mm. ;-) The default left and right margin is 0.75 inch. The default top and bottom margin is 1.00 inch. 
+
+
+
+=head2 set_header($string, $margin)
+
+Headers and footers are generated using a C<$string> which is a combination of plain text and control characters. The C<$margin> parameter is optional.
+
+The available control character are:
+
+    Control              Type             Description
+    =======              ====             ===========
+    &L                   Justification    Left
+    &C                                    Center
+    &R                                    Right
+    
+    &P                   Information      Page number
+    &N                                    Total number of pages
+    &D                                    Date
+    &T                                    Time
+    &F                                    File name
+    &A                                    Worksheet name
+    
+    &fontsize            Font             Font size
+    &"fontname,style"                     Font name and style
+    
+    
+
+Text in headers and footers can be justified (aligned) to the left, center and right by prefixing the text with the control characters C<&L>, C<&C> and C<&R>.
+
+For example (with ASCII art representation of the results):
+
+    $worksheet->set_header('&LHello');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    | Hello                                                         |
+    |                                                               |
+    
+    
+    $worksheet->set_header('&CHello');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    |                          Hello                                |
+    |                                                               |
+    
+    
+    $worksheet->set_header('&RHello');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    |                                                         Hello |
+    |                                                               |
+    
+
+If you do not specify any justification the text will be centered:
+
+    $worksheet->set_header('Hello');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    |                          Hello                                |
+    |                                                               |
+    
+
+You can also have text in each of the justification regions:
+
+    $worksheet->set_header('&LCiao&CBello&RCielo');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    | Ciao                     Bello                          Cielo |
+    |                                                               |
+    
+
+The information control characters act as variables that Excel will update as the workbook or worksheet changes. Times and dates are in the users default format:
+
+    $worksheet->set_header('Page &P of &N');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    |                        Page 1 of 6                            |
+    |                                                               |
+    
+    
+    $worksheet->set_header('Updated at &T');
+    
+     ---------------------------------------------------------------
+    |                                                               |
+    |                    Updated at 12:30 PM                        |
+    |                                                               |
+    
+
+
+You can specify the font size of a section of the text by prefixing it with the control character C<&n> where C<n> is the font size:
+
+    $worksheet->set_header('&20Big Hello');
+    $worksheet->set_header('&6Small Hello');
+
+You can specify the font of a section of the text by prefixing it with the control sequence C<&"fontname,style"> where C<fontname> is a font name such as "Courier New" or "Times New Roman" and C<style> is one of the standard Windows font descriptions: "Regular", "Italic", "Bold" or "Bold Italic":
+
+    $worksheet1->set_header('&"Courier New,Italic"Hello');
+    $worksheet2->set_header('&"Courier New,Bold Italic"Hello');
+    $worksheet3->set_header('&"Times New Roman,Regular"Hello');
+
+It is possible to combine all of these features together to create sophisticated headers and footers. As an aid to setting up complicated headers and footers you can record a page setup as a macro in Excel and look at the format strings that VBA produces. Remember however that VBA uses a double double quote C<""> to indicate a single double quote. For the last example above the equivalent VBA code looks like this:
+
+    .LeftHeader   = ""
+    .CenterHeader = "&""Times New Roman,Regular""Hello"
+    .RightHeader  = ""
+
+The header or footer string must be less than 255 characters.
+
+As stated above the margin parameter is optional. As with the other margins the value should be in inches. The default header and footer margin is 0.50 inch. The header and footer margin size can be set as follows:
+
+    $worksheet->set_header('&CHello', 0.75);
+
+Note, the header and footer margins are independent of the top and bottom margins.
+
+
+
+=head2 set_footer()
+
+See the C<set_header()> section above.
+
 
 
 
@@ -1194,14 +1510,14 @@ The following table lists all of the core functions supported by Excel 5 and Spr
 
 You can also modify the module to support function names in the following languages: German, French, Spanish, Portuguese, Dutch, Finnish, Italian and Swedish. See the C<function_locale.pl> program in the C<examples> directory of the distro.
 
-For a general introduction to Excel's formulas and an explanation of the functions have a look at the Excel help files or the following links: http://msdn.microsoft.com/library/default.asp?URL=/library/officedev/office97/s88f2.htm and http://msdn.microsoft.com/library/default.asp?URL=/library/officedev/office97/s992f.htm
+For a general introduction to Excel's formulas and an explanation of the syntax of the function refer to the Excel help files or the following links: http://msdn.microsoft.com/library/default.asp?URL=/library/officedev/office97/s88f2.htm and http://msdn.microsoft.com/library/default.asp?URL=/library/officedev/office97/s992f.htm
 
 
 If your formula doesn't work in Spreadsheet::WriteExcel try the following:
 
     1. Verify that the formula works in Excel (or Gnumeric or OpenOffice).
     2. Ensure that it isn't on the TODO list at the start of this section.
-    3. Ensure that cell references and cell names are in uppercase.
+    3. Ensure that cell references and formula names are in uppercase.
     4. Ensure that you are using the U.S. style range and union operators.
     5. Ensure the function is in the above table.
 
@@ -1567,13 +1883,13 @@ The BIFF data is stored along with other data in an OLE Compound File. This is a
 
 The documentation for the OLE::Storage module, http://user.cs.tu-berlin.de/~schwartz/pmh/guide.html , contains one of the few descriptions of the OLE Compound File in the public domain.
 
-For a open source implementation of the OLE library see the 'cole' library at http://arturo.directmail.org/filtersweb/
+For a open source implementation of the OLE library see the 'cole' library at http://atena.com/libole2.php
 
 The source code for the Excel plugin of the Gnumeric spreadsheet also contains information relevant to the Excel BIFF format and the OLE container, http://www.gnumeric.org/gnumeric
 
 In addition the source code for OpenOffice is available at http://www.openoffice.org/
 
-An article describing Spreadsheet::WriteExcel and how it works appears in Issue #19 of The Perl Journal, http://www.itknowledge.com/tpj/ It is reproduced, by kind permission, in the C<doc> directory of the distro.
+An article describing Spreadsheet::WriteExcel and how it works appears in Issue #19 of The Perl Journal, http://www.tpj.com/ It is reproduced, by kind permission, in the C<doc> directory of the distro.
 
 
 Please note that the provision of this information does not constitute an invitation to start hacking at the BIFF or OLE file formats. There are more interesting ways to waste your time. ;-)
@@ -1589,7 +1905,9 @@ Depending on your requirements, background and general sensibilities you may pre
 
 * DBI with DBD::ADO or DBD::ODBC. Excel files contain an internal index table that allows them to act like a database file. Using one of the standard Perl database modules you can connect to an Excel file as a database.
 
-* Win32::OLE module and office automation. This requires a Windows platform and an installed copy of Excel. This is the most powerful and complete method for interfacing with Excel. See http://velocity.activestate.com/docs/ActivePerl/faq/Windows/ActivePerl-Winfaq12.html and http://velocity.activestate.com/docs/ActivePerl/site/lib/Win32/OLE.html If your main platform is UNIX but you have the resources to set up a separate Win32/MSOffice server, you can convert office documents to text, postscript or PDF using Win32::OLE. For a demonstration of how to do this using Perl see Docserver: http://search.cpan.org/search?mode=module&query=docserver
+* DBI::Excel, you can also access Spreadsheet::WriteExcel using the standard DBI interface via Kawai Takanori's DBI::Excel module http://search.cpan.org/search?dist=DBI-Excel.
+
+* Win32::OLE module and office automation. This requires a Windows platform and an installed copy of Excel. This is the most powerful and complete method for interfacing with Excel. See http://www.activestate.com/ASPN/Reference/Products/ActivePerl-5.6/faq/Windows/ActivePerl-Winfaq12.html and http://www.activestate.com/ASPN/Reference/Products/ActivePerl-5.6/site/lib/Win32/OLE.html If your main platform is UNIX but you have the resources to set up a separate Win32/MSOffice server, you can convert office documents to text, postscript or PDF using Win32::OLE. For a demonstration of how to do this using Perl see Docserver: http://search.cpan.org/search?mode=module&query=docserver
 
 * HTML tables. This is an easy way of adding formatting.
 
@@ -1604,15 +1922,19 @@ To read data from Excel files try:
 
 * Spreadsheet::ParseExcel. This uses the OLE::Storage-Lite module to extract data from an Excel file. http://search.cpan.org/search?dist=Spreadsheet-ParseExcel
 
-* OLE::Storage, aka LAOLA. This is a Perl interface to OLE file formats. In particular, the distro contains an Excel to HTML converter called Herbert, http://user.cs.tu-berlin.de/~schwartz/pmh/ This has been superseded by the Spreadsheet::ParseExcel module. There is also an open source C/C++ project based on the LAOLA work. Try the Filters Project http://arturo.directmail.org/filtersweb/ and the Excel to HTML converter at the xlHtml Project http://www.xlhtml.org/
+* OLE::Storage, aka LAOLA. This is a Perl interface to OLE file formats. In particular, the distro contains an Excel to HTML converter called Herbert, http://user.cs.tu-berlin.de/~schwartz/pmh/ This has been superseded by the Spreadsheet::ParseExcel module. There is also an open source C/C++ project based on the LAOLA work. Try the Filters Project http://atena.com/libole2.php and the Excel to HTML converter at the xlHtml Project http://www.xlhtml.org/
 
 * HTML tables. If the files are saved from Excel in a HTML format the data can be accessed using HTML::TableExtract http://search.cpan.org/search?dist=HTML-TableExtract
 
 * DBI with DBD::ADO or DBD::ODBC. See, the section L<WRITING EXCEL FILES>.
 
+* DBI::Excel, you can also access Spreadsheet::ParseExcel using the standard DBI interface via Kawai Takanori's DBI::Excel module http://search.cpan.org/search?dist=DBI-Excel.
+
+* XML::Excel converts Excel files to XML using Spreadsheet::ParseExcel http://search.cpan.org/search?dist=XML-Excel. 
+
 * Win32::OLE module and office automation. See, the section L<WRITING EXCEL FILES>.
 
-If you wish to view Excel files on a UNIX/Linux platform check out the excellent Gnumeric spreadsheet application at http://www.gnumeric.org/gnumeric or OpenOffice at http://www.openoffice.org/
+If you wish to view Excel files on a UNIX/Linux platform check out the excellent Gnumeric spreadsheet application at http://www.gnome.org/projects/gnumeric/ or OpenOffice at http://www.openoffice.org/
 
 If you wish to view Excel files on a Windows platform which doesn't have Excel installed you can use the free Microsoft Excel Viewer http://officeupdate.microsoft.com/2000/downloaddetails/xlviewer.htm
 
@@ -1643,27 +1965,42 @@ The lack of a portable way of writing a little-endian 64 bit IEEE float.
 
 The roadmap is as follows:
 
-    * Add page set-up features. [1]
-    * Move to Excel97/2000 format as standard. [2]
-    * Exeunt. [3]
+=over
 
-Note 1. Margins, orientation, sheet size, headers, footers, panes and anything else that looks viable.
+=item * More page set-up features. The aim is to support all the page setup features that are available through Excel's page setup dialog. Also vertical and horizontal page breaks will be added.
 
-Note 2. This will allow strings greater than 255 characters (who thought up that limit) and hopefully Unicode. The Excel 5 format will be optional.
+=item * Add cell protection and formula hiding.
 
-Note 3. The module will eventually move to a maintenance only state. As such items 1 and 2 are the last major elements in the closed set of features. Each new feature requires coding (the easy part), testing and documentation and in turn adds to the complexity of the interface. Also, programming in Perl should not require this much use of a hex editor. :-)
+=item * Add handling for non-English formula syntax and numbers in different locales.
 
+=item * Move to Excel97/2000 format as standard. This will allow strings greater than 255 characters (who thought up that limit) and hopefully Unicode. The Excel 5 format will be optional.
+
+=back
+
+Also, here are some of the most requested features that probably won't get added:
+
+=over
+
+=item * Graphs. The format is documented but it would require too much work to implement. It would also require too much work to design a useable interface to the hundreds of features in an Excel graph. So that's two too much works.
+
+=item * Macros. This would solve the previous problem neatly. However, the format of Excel macros isn't documented.
+
+=item * Some feature that you really need. ;-)
+
+=back
+
+If there is some feature of an Excel file that you really, really need then you should use Win32::OLE with Excel on Windows. If you are on Unix, then set up a Windows server and use SOAP or CORBA or get your clients to use Gnumeric, it's better than Excel anyway.
 
 
 =head1 ACKNOWLEDGEMENTS
 
 The following people contributed to the debugging and testing of Spreadsheet::WriteExcel:
 
-Alexander Farber, Arthur@ais, Artur Silveira da Cunha, Borgar Olsen, Cedric Bouvier, CPAN testers, Daniel Gardner, Harold Bamford, James Holmes, Johan Ekenberg, J.C. Wren, Kenneth Stacey, Michael Buschauer, Mike Blazer, Paul J. Falbe, Paul Medynski, Peter Dintelmann, Rich Sorden, Shane Ashby, Shenyu Zheng.
+Alexander Farber, Arthur@ais, Artur Silveira da Cunha, Borgar Olsen, Cedric Bouvier, CPAN testers, Daniel Berger, Daniel Gardner, Harold Bamford, James Holmes, Johan Ekenberg, J.C. Wren, Kenneth Stacey, Michael Buschauer, Mike Blazer, Paul J. Falbe, Paul Medynski, Peter Dintelmann, Rich Sorden, Shane Ashby, Shenyu Zheng.
 
 The following people contributed code or examples:
 
-Andrew Benham, Marco Geri, Sam Kington, Takanori Kawai, Tom O'Sullivan.
+Andrew Benham, Bill Young, Marco Geri, Sam Kington, Takanori Kawai, Tom O'Sullivan.
 
 Additional thanks to Takanori Kawai for translating the documentation into Japanese: http://member.nifty.ne.jp/hippo2000/perltips/Spreadsheet/WriteExcel.htm
 
@@ -1677,13 +2014,21 @@ Thanks to Damian Conway for the excellent Parse::RecDescent. Thanks to Michael M
 John McNamara jmcnamara@cpan.org
 
 
-    Caught between the twisted stars
-    The plotted lines the faulty map
-    That brought Columbus to New York.
-    Betwixt between the East and West
-    He calls on her wearing a leather vest
-    The earth squeals and shudders to a halt.
-        --Lou Reed
+    Waking up from bad dreams and smoking cigarettes
+    Cuddling a warm girl and smelling stale perfume
+    A hot summer's day, and sticky black tarmac
+    Feeding ducks in the park, and wishing you were far away
+    
+    That's entertainment
+    
+    Two lovers kissing amongst the scream of midnight
+    Two lovers missing the tranquility of solitude
+    Getting a cab and travelling on buses
+    Reading the graffiti about slash-seat affairs
+    
+    That's entertainment.
+    
+        --Paul Weller
 
 
 =head1 COPYRIGHT
