@@ -12,8 +12,7 @@ package Spreadsheet::WriteExcel::BIFFwriter;
 # Documentation after __END__
 #
 
-require Exporter;
-
+use Exporter;
 use strict;
 
 
@@ -21,6 +20,7 @@ use strict;
 
 
 
+
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
 
