@@ -12,8 +12,7 @@ package Spreadsheet::WriteExcel::Worksheet;
 # Documentation after __END__
 #
 
-require Exporter;
-
+use Exporter;
 use strict;
 use Carp;
 use Spreadsheet::WriteExcel::BIFFwriter;
@@ -21,10 +20,11 @@ use Spreadsheet::WriteExcel::Format;
 use Spreadsheet::WriteExcel::Formula;
 
 
+
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::WriteExcel::BIFFwriter);
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 ###############################################################################
 #
@@ -61,7 +61,23 @@ sub new {
     $self->{_dim_colmax}    = 0;
     $self->{_colinfo}       = [];
     $self->{_selection}     = [0, 0];
+    $self->{_panes}         = [];
+    $self->{_active_pane}   = 3;
+    $self->{_frozen}        = 0;
+    $self->{_selected}      = 0;
 
+    $self->{_paper_size}    = 0x0;
+    $self->{_orientation}   = 0x1;
+    $self->{_header}        = '';
+    $self->{_footer}        = '';
+    $self->{_hcenter}       = 0;
+    $self->{_vcenter}       = 0;
+    $self->{_margin_head}   = 0.50;
+    $self->{_margin_foot}   = 0.50;
+    $self->{_margin_left}   = 0.75;
+    $self->{_margin_right}  = 0.75;
+    $self->{_margin_top}    = 1.00;
+    $self->{_margin_bottom} = 1.00;
 
     bless $self, $class;
     $self->_initialize();
@@ -111,13 +127,40 @@ sub _close {
     my $sheetnames = shift;
     my $num_sheets = scalar @$sheetnames;
 
-    #
+    ################################################
     # Prepend in reverse order!!
     #
 
     # Prepend the sheet dimensions
     $self->_store_dimensions();
 
+    # Prepend the page setup
+    $self->_store_setup();
+
+    # Prepend the bottom margin
+    $self->_store_margin_bottom();
+
+    # Prepend the top margin
+    $self->_store_margin_top();
+
+    # Prepend the right margin
+    $self->_store_margin_right();
+
+    # Prepend the left margin
+    $self->_store_margin_left();
+
+    # Prepend the page vertical centering
+    $self->_store_vcenter();
+
+    # Prepend the page horizontal centering
+    $self->_store_hcenter();
+
+    # Prepend the page footer
+    $self->_store_footer();
+
+    # Prepend the page header
+    $self->_store_header();
+
     # Prepend EXTERNSHEET references
     for (my $i = $num_sheets; $i > 0; $i--) {
         my $sheetname = @{$sheetnames}[$i-1];
@@ -139,10 +182,13 @@ sub _close {
     # Prepend the BOF record
     $self->_store_bof(0x0010);
 
+    #
     # End of prepend. Read upwards from here.
+    ################################################
 
     # Append
     $self->_store_window2();
+    $self->_store_panes(@{$self->{_panes}}) if @{$self->{_panes}};
     $self->_store_selection(@{$self->{_selection}});
     $self->_store_eof();
 }
@@ -160,7 +206,7 @@ sub _append {
     my $self = shift;
 
     if ($self->{_using_tmpfile}) {
-        my $data    = join('', @_);
+        my $data = join('', @_);
         print {$self->{_filehandle}} $data;
         $self->{_datasize} += length($data);
     }
@@ -193,8 +239,8 @@ sub get_name {
 #
 sub get_data {
 
-    my $self    = shift;
-    my $buffer  = 4096;
+    my $self   = shift;
+    my $buffer = 4096;
     my $tmp;
 
     # Return data stored in memory
@@ -216,17 +262,33 @@ sub get_data {
 }
 
 
+###############################################################################
+#
+# select()
+#
+# Set this worksheet as a selected worksheet, i.e. the worksheet has its tab
+# highlighted.
+#
+sub select {
+
+    my $self = shift;
+
+    $self->{_selected} = 1;
+}
+
+
 ###############################################################################
 #
 # activate()
 #
-# Set this worksheet as the selected worksheet, i.e. the worksheet
-# with its tab highlighted.
+# Set this worksheet as the active worksheet, i.e. the worksheet that is
+# displayed when the workbook is opened. Also set it as selected.
 #
 sub activate {
 
     my $self = shift;
 
+    $self->{_selected} = 1;
     ${$self->{_activesheet}} = $self->{_index};
 }
 
@@ -257,7 +319,7 @@ sub set_first_sheet {
 sub set_column {
 
     my $self = shift;
-    my $cell  = $_[0];
+    my $cell = $_[0];
 
     # Check for a cell reference in A1 notation and substitute row and column
     if ($cell =~ /^\D/) {
@@ -303,6 +365,254 @@ sub set_selection {
 }
 
 
+###############################################################################
+#
+# freeze_panes()
+#
+# Set panes and mark them as frozen. See also _store_panes().
+#
+sub freeze_panes {
+
+    my $self = shift;
+
+    # Check for a cell reference in A1 notation and substitute row and column
+    if ($_[0] =~ /^\D/) {
+        @_ = $self->_substitute_cellref(@_);
+    }
+
+    $self->{_frozen} = 1;
+    $self->{_panes}  = [ @_ ];
+}
+
+
+###############################################################################
+#
+# thaw_panes()
+#
+# Set panes and mark them as unfrozen. See also _store_panes().
+#
+sub thaw_panes {
+
+    my $self = shift;
+
+    $self->{_frozen} = 0;
+    $self->{_panes}  = [ @_ ];
+}
+
+
+###############################################################################
+#
+# set_portrait()
+#
+# Set the page orientation as portrait.
+#
+sub set_portrait {
+
+    my $self = shift;
+
+    $self->{_orientation} = 1;
+}
+
+
+###############################################################################
+#
+# set_landscape()
+#
+# Set the page orientation as landscape.
+#
+sub set_landscape {
+
+    my $self = shift;
+
+    $self->{_orientation} = 0;
+}
+
+
+###############################################################################
+#
+# set_paper()
+#
+# Set the paper type. Ex. 1 = US Letter, 9 = A4
+#
+sub set_paper {
+
+    my $self = shift;
+
+    $self->{_paper_size} = $_[0] || 0;
+}
+
+
+###############################################################################
+#
+# set_header()
+#
+# Set the page header caption and optional margin.
+#
+sub set_header {
+
+    my $self = shift;
+
+    $self->{_header}      = $_[0] || '';
+    $self->{_margin_head} = $_[1] || 0.50;
+}
+
+
+###############################################################################
+#
+# set_footer()
+#
+# Set the page footer caption and optional margin.
+#
+sub set_footer {
+
+    my $self = shift;
+
+    $self->{_footer}      = $_[0] || '';
+    $self->{_margin_foot} = $_[1] || 0.50;
+}
+
+
+###############################################################################
+#
+# center_horizontally()
+#
+# Center the page horinzontally.
+#
+sub center_horizontally {
+
+    my $self = shift;
+
+    if (defined $_[0]) {
+        $self->{_hcenter} = $_[0];
+    }
+    else {
+        $self->{_hcenter} = 1;
+    }
+}
+
+
+###############################################################################
+#
+# center_vertically()
+#
+# Center the page horinzontally.
+#
+sub center_vertically {
+
+    my $self = shift;
+
+    if (defined $_[0]) {
+        $self->{_vcenter} = $_[0];
+    }
+    else {
+        $self->{_vcenter} = 1;
+    }
+}
+
+
+###############################################################################
+#
+# set_margins()
+#
+# Set all the page margins to the same value in inches.
+#
+sub set_margins {
+
+    my $self = shift;
+
+    $self->set_margin_left($_[0]);
+    $self->set_margin_right($_[0]);
+    $self->set_margin_top($_[0]);
+    $self->set_margin_bottom($_[0]);
+}
+
+
+###############################################################################
+#
+# set_margins_LR()
+#
+# Set the left and right margins to the same value in inches.
+#
+sub set_margins_LR {
+
+    my $self = shift;
+
+    $self->set_margin_left($_[0]);
+    $self->set_margin_right($_[0]);
+}
+
+
+###############################################################################
+#
+# set_margins_TB()
+#
+# Set the top and bottom margins to the same value in inches.
+#
+sub set_margins_TB {
+
+    my $self = shift;
+
+    $self->set_margin_top($_[0]);
+    $self->set_margin_bottom($_[0]);
+}
+
+
+###############################################################################
+#
+# set_margin_left()
+#
+# Set the left margin in inches.
+#
+sub set_margin_left {
+
+    my $self = shift;
+
+    $self->{_margin_left} = $_[0] || 0.75;
+}
+
+
+###############################################################################
+#
+# set_margin_right()
+#
+# Set the right margin in inches.
+#
+sub set_margin_right {
+
+    my $self = shift;
+
+    $self->{_margin_right} = $_[0] || 0.75;
+}
+
+
+###############################################################################
+#
+# set_margin_top()
+#
+# Set the top margin in inches.
+#
+sub set_margin_top {
+
+    my $self = shift;
+
+    $self->{_margin_top} = $_[0] || 1.00;
+}
+
+
+###############################################################################
+#
+# set_margin_bottom()
+#
+# Set the bottom margin in inches.
+#
+sub set_margin_bottom {
+
+    my $self = shift;
+
+    $self->{_margin_bottom} = $_[0] || 1.00;
+}
+
+
 ###############################################################################
 #
 # _XF()
@@ -333,7 +643,7 @@ sub _XF {
 #
 sub write {
 
-    my $self  = shift;
+    my $self = shift;
 
     # Check for a cell reference in A1 notation and substitute row and column
     if ($_[0] =~ /^\D/) {
@@ -429,10 +739,10 @@ sub _cell_to_rowcol {
     my $row     = $2;
 
     # Convert base26 column string to number
-    # All your base are belong to us.
-    my @chars  = split //, $col;
-    my $expn   = 0;
-    $col       = 0;
+    # All your Base are belong to us.
+    my @chars = split //, $col;
+    my $expn  = 0;
+    $col      = 0;
 
     while (@chars) {
         my $char = pop(@chars); # LS char first
@@ -827,18 +1137,39 @@ sub _store_dimensions {
 #
 sub _store_window2 {
 
-    my $self    = shift;
-    my $record  = 0x023E;     # Record identifier
-    my $length  = 0x000A;     # Number of bytes to follow
+    my $self           = shift;
+    my $record         = 0x023E;     # Record identifier
+    my $length         = 0x000A;     # Number of bytes to follow
 
-    my $grbit   = 0x00B6;     # Option flags
-    my $rwTop   = 0x0000;     # Top row visible in window
-    my $colLeft = 0x0000;     # Leftmost column visible in window
-    my $rgbHdr  = 0x00000000; # Row/column heading and gridline color
+    my $grbit          = 0x00B6;     # Option flags
+    my $rwTop          = 0x0000;     # Top row visible in window
+    my $colLeft        = 0x0000;     # Leftmost column visible in window
+    my $rgbHdr         = 0x00000000; # Row/column heading and gridline color
 
-    if (${$self->{_activesheet}} == $self->{_index}) {
-        $grbit = 0x06B6;
-    }
+    # The options flags that comprise $grbit
+    my $fDspFmla       = 0;                     # 0 - bit
+    my $fDspGrid       = 1;                     # 1
+    my $fDspRwCol      = 1;                     # 2
+    my $fFrozen        = $self->{_frozen};      # 3
+    my $fDspZeros      = 1;                     # 4
+    my $fDefaultHdr    = 1;                     # 5
+    my $fArabic        = 0;                     # 6
+    my $fDspGuts       = 1;                     # 7
+    my $fFrozenNoSplit = 0;                     # 0 - bit
+    my $fSelected      = $self->{_selected};    # 1
+    my $fPaged         = 1;                     # 2
+
+    $grbit             = $fDspFmla;
+    $grbit            |= $fDspGrid       << 1;
+    $grbit            |= $fDspRwCol      << 2;
+    $grbit            |= $fFrozen        << 3;
+    $grbit            |= $fDspZeros      << 4;
+    $grbit            |= $fDefaultHdr    << 5;
+    $grbit            |= $fArabic        << 6;
+    $grbit            |= $fDspGuts       << 7;
+    $grbit            |= $fFrozenNoSplit << 8;
+    $grbit            |= $fSelected      << 9;
+    $grbit            |= $fPaged         << 10;
 
     my $header  = pack("vv",   $record, $length);
     my $data    = pack("vvvV", $grbit, $rwTop, $colLeft, $rgbHdr);
@@ -912,19 +1243,19 @@ sub _store_colinfo {
 sub _store_selection {
 
     my $self     = shift;
-    my $record   = 0x001D;              # Record identifier
-    my $length   = 0x000F;              # Number of bytes to follow
+    my $record   = 0x001D;                  # Record identifier
+    my $length   = 0x000F;                  # Number of bytes to follow
 
-    my $pnn      = 3;                   # Pane position
-    my $rwAct    = $_[0];               # Active row
-    my $colAct   = $_[1];               # Active column
-    my $irefAct  = 0;                   # Active cell ref
-    my $cref     = 1;                   # Number of refs
+    my $pnn      = $self->{_active_pane};   # Pane position
+    my $rwAct    = $_[0];                   # Active row
+    my $colAct   = $_[1];                   # Active column
+    my $irefAct  = 0;                       # Active cell ref
+    my $cref     = 1;                       # Number of refs
 
-    my $rwFirst  = $_[0];               # First row in reference
-    my $colFirst = $_[1];               # First col in reference
-    my $rwLast   = $_[2] || $rwFirst;   # Last  row in reference
-    my $colLast  = $_[3] || $colFirst;  # Last  col in reference
+    my $rwFirst  = $_[0];                   # First row in reference
+    my $colFirst = $_[1];                   # First col in reference
+    my $rwLast   = $_[2] || $rwFirst;       # Last  row in reference
+    my $colLast  = $_[3] || $colFirst;      # Last  col in reference
 
     # Swap last row/col for first row/col as necessary
     if ($rwFirst > $rwLast) {
@@ -1017,6 +1348,326 @@ sub _store_externsheet {
 }
 
 
+###############################################################################
+#
+# _store_panes()
+#
+#
+# Writes the Excel BIFF PANE record.
+# The panes can either be frozen or thawed (unfrozen).
+# Frozen panes are specified in terms of a integer number of rows and columns.
+# Thawed panes are specified in terms of Excel's units for rows and columns.
+#
+sub _store_panes {
+
+    my $self    = shift;
+    my $record  = 0x0041;       # Record identifier
+    my $length  = 0x000A;       # Number of bytes to follow
+
+    my $y       = $_[0] || 0;   # Vertical split position
+    my $x       = $_[1] || 0;   # Horizontal split position
+    my $rwTop   = $_[2];        # Top row visible
+    my $colLeft = $_[3];        # Leftmost column visible
+    my $pnnAct  = $_[4];        # Active pane
+
+
+    # Code specific to frozen or thawed panes.
+    if ($self->{_frozen}) {
+        # Set default values for $rwTop and $colLeft
+        $rwTop   = $y unless defined $rwTop;
+        $colLeft = $x unless defined $colLeft;
+    }
+    else {
+        # Set default values for $rwTop and $colLeft
+        $rwTop   = 0  unless defined $rwTop;
+        $colLeft = 0  unless defined $colLeft;
+
+        # Convert Excel's row and column units to the internal units.
+        # The default row height is 12.75
+        # The default column width is 8.43
+        # The following slope and intersection values were interpolated.
+        #
+        $y = 20*$y      + 255;
+        $x = 113.879*$x + 390;
+    }
+
+
+    # Determine which pane should be active. There is also the undocumented
+    # option to override this should it be neccessary: may be removed later.
+    #
+    if (not defined $pnnAct) {
+        $pnnAct = 0 if ($x != 0 && $y != 0); # Bottom right
+        $pnnAct = 1 if ($x != 0 && $y == 0); # Top right
+        $pnnAct = 2 if ($x == 0 && $y != 0); # Bottom left
+        $pnnAct = 3 if ($x == 0 && $y == 0); # Top left
+    }
+
+    $self->{_active_pane} = $pnnAct; # Used in _store_selection
+
+    my $header     = pack("vv",    $record, $length);
+    my $data       = pack("vvvvv", $x, $y, $rwTop, $colLeft, $pnnAct);
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_setup()
+#
+# Store the page setup SETUP BIFF record.
+#
+sub _store_setup {
+
+    my $self         = shift;
+    my $record       = 0x00A1;                  # Record identifier
+    my $length       = 0x0022;                  # Number of bytes to follow
+
+    my $iPaperSize   = $self->{_paper_size};    # Paper size
+    my $iScale       = 0x64;                    # Scaling factor
+    my $iPageStart   = 0x01;                    # Starting page number
+    my $iFitWidth    = 0x01;                    # Fit to width
+    my $iFitHeight   = 0x01;                    # Fit to height
+    my $grbit        = 0x00;                    # Option flags
+    my $iRes         = 0x0258;                  # Print resolution
+    my $iVRes        = 0x0258;                  # Vertical print resolution
+    my $numHdr       = $self->{_margin_head};   # Header Margin
+    my $numFtr       = $self->{_margin_foot};   # Footer Margin
+    my $iCopies      = 0x01;                    # Number of copies
+
+
+    my $fLeftToRight = 0x0;                     # Print over then down
+    my $fLandscape   = $self->{_orientation};   # Page orientation
+    my $fNoPls       = 0x0;                     # Setup not read from printer
+    my $fNoColor     = 0x0;                     # Print black and white
+    my $fDraft       = 0x0;                     # Print draft quality
+    my $fNotes       = 0x0;                     # Print notes
+    my $fNoOrient    = 0x0;                     # Orientation not set
+    my $fUsePage     = 0x0;                     # Use custom starting page
+
+
+    $grbit           = $fLeftToRight;
+    $grbit          |= $fLandscape    << 1;
+    $grbit          |= $fNoPls        << 2;
+    $grbit          |= $fNoColor      << 3;
+    $grbit          |= $fDraft        << 4;
+    $grbit          |= $fNotes        << 5;
+    $grbit          |= $fNoOrient     << 6;
+    $grbit          |= $fUsePage      << 7;
+
+
+    $numHdr = pack("d", $numHdr);
+    $numFtr = pack("d", $numFtr);
+
+    if ($self->{_byte_order}) {
+        $numHdr = reverse $numHdr;
+        $numFtr = reverse $numFtr;
+    }
+
+    my $header = pack("vv",         $record, $length);
+    my $data1  = pack("vvvvvvvv",   $iPaperSize,
+                                    $iScale,
+                                    $iPageStart,
+                                    $iFitWidth,
+                                    $iFitHeight,
+                                    $grbit,
+                                    $iRes,
+                                    $iVRes);
+    my $data2  = $numHdr .$numFtr;
+    my $data3  = pack("v", $iCopies);
+
+    $self->_prepend($header, $data1, $data2, $data3);
+
+}
+
+###############################################################################
+#
+# _store_header()
+#
+# Store the header caption BIFF record.
+#
+sub _store_header {
+
+    my $self    = shift;
+
+    my $record  = 0x0014;               # Record identifier
+    my $length;                         # Bytes to follow
+
+    my $str     = $self->{_header};     # header string
+    my $cch     = length($str);         # Length of header string
+    $length     = 1 + $cch;
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("C",   $cch);
+
+    $self->_append($header, $data, $str);
+}
+
+
+###############################################################################
+#
+# _store_footer()
+#
+# Store the footer caption BIFF record.
+#
+sub _store_footer {
+
+    my $self    = shift;
+
+    my $record  = 0x0015;               # Record identifier
+    my $length;                         # Bytes to follow
+
+    my $str     = $self->{_footer};     # Footer string
+    my $cch     = length($str);         # Length of footer string
+    $length     = 1 + $cch;
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("C",   $cch);
+
+    $self->_append($header, $data, $str);
+}
+
+
+###############################################################################
+#
+# _store_hcenter()
+#
+# Store the horizontal centering HCENTER BIFF record.
+#
+sub _store_hcenter {
+
+    my $self     = shift;
+
+    my $record   = 0x0083;              # Record identifier
+    my $length   = 0x0002;              # Bytes to follow
+
+    my $fHCenter = $self->{_hcenter};   # Horizontal centering
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("v",   $fHCenter);
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_vcenter()
+#
+# Store the vertical centering VCENTER BIFF record.
+#
+sub _store_vcenter {
+
+    my $self     = shift;
+
+    my $record   = 0x0084;              # Record identifier
+    my $length   = 0x0002;              # Bytes to follow
+
+    my $fVCenter = $self->{_vcenter};   # Horizontal centering
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("v",   $fVCenter);
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_margin_left()
+#
+# Store the LEFTMARGIN BIFF record.
+#
+sub _store_margin_left {
+
+    my $self    = shift;
+
+    my $record  = 0x0026;                   # Record identifier
+    my $length  = 0x0008;                   # Bytes to follow
+
+    my $margin  = $self->{_margin_left};    # Margin in inches
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("d",   $margin);
+
+    if ($self->{_byte_order}) { $data = reverse $data }
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_margin_right()
+#
+# Store the RIGHTMARGIN BIFF record.
+#
+sub _store_margin_right {
+
+    my $self    = shift;
+
+    my $record  = 0x0027;                   # Record identifier
+    my $length  = 0x0008;                   # Bytes to follow
+
+    my $margin  = $self->{_margin_right};   # Margin in inches
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("d",   $margin);
+
+    if ($self->{_byte_order}) { $data = reverse $data }
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_margin_top()
+#
+# Store the TOPMARGIN BIFF record.
+#
+sub _store_margin_top {
+
+    my $self    = shift;
+
+    my $record  = 0x0028;                   # Record identifier
+    my $length  = 0x0008;                   # Bytes to follow
+
+    my $margin  = $self->{_margin_top};     # Margin in inches
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("d",   $margin);
+
+    if ($self->{_byte_order}) { $data = reverse $data }
+
+    $self->_append($header, $data);
+}
+
+
+###############################################################################
+#
+# _store_margin_bottom()
+#
+# Store the BOTTOMMARGIN BIFF record.
+#
+sub _store_margin_bottom {
+
+    my $self    = shift;
+
+    my $record  = 0x0029;                   # Record identifier
+    my $length  = 0x0008;                   # Bytes to follow
+
+    my $margin  = $self->{_margin_bottom};  # Margin in inches
+
+    my $header    = pack("vv",  $record, $length);
+    my $data      = pack("d",   $margin);
+
+    if ($self->{_byte_order}) { $data = reverse $data }
+
+    $self->_append($header, $data);
+}
+
+
 1;
 
 
